@@ -1,5 +1,3 @@
-context("test-zip.R")
-
 test_that("jst_preview_zip works", {
   correct_res <- tribble(
     ~type, ~meta_type, ~n,
@@ -45,7 +43,7 @@ test_that("importing from zip works", {
   
   # test for the content of the files
   test_expected_zip <- function(expected_file) {
-    expect_identical(read_csv(file.path("testfiles", expected_file)),
+    expect_equal(read_csv(file.path("testfiles", expected_file)),
                      read_csv(file.path(test_dir, expected_file)))
   }
   expected_files %>% 
